@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.41";
+our $VERSION = "1.4101";
 
 use v5.14;
 use warnings;
@@ -544,7 +544,7 @@ sub table_out {
 			print "\n";
 		    } else {
 			use integer;
-			print "\t" x (($tabs[$fx] - $length[$lx][$fx] + $cu - 1) / $cu);
+			print "\t" x div($tabs[$fx] - $length[$lx][$fx], $cu);
 		    }
 		}
 	    }
